@@ -35,7 +35,6 @@
 #include "ephy-flatpak-utils.h"
 #include "ephy-history-service.h"
 #include "ephy-password-manager.h"
-#include "ephy-pdf-handler.h"
 #include "ephy-profile-utils.h"
 #include "ephy-reader-handler.h"
 #include "ephy-settings.h"
@@ -66,7 +65,6 @@ typedef struct {
   EphyAboutHandler *about_handler;
   EphyViewSourceHandler *source_handler;
   EphyReaderHandler *reader_handler;
-  EphyPDFHandler *pdf_handler;
   char *guid;
   EphyFiltersManager *filters_manager;
   EphySearchEngineManager *search_engine_manager;
@@ -196,7 +194,6 @@ ephy_embed_shell_dispose (GObject *object)
   g_clear_object (&priv->about_handler);
   g_clear_object (&priv->reader_handler);
   g_clear_object (&priv->source_handler);
-  g_clear_object (&priv->pdf_handler);
   g_clear_object (&priv->downloads_manager);
   g_clear_object (&priv->password_manager);
   g_clear_object (&priv->permissions_manager);
@@ -340,7 +337,7 @@ web_process_extension_about_apps_message_received_cb (WebKitUserContentManager *
   g_autofree char *app_id = NULL;
 
   app_id = jsc_value_to_string (webkit_javascript_result_get_js_value (message));
-  ephy_web_application_delete (app_id);
+  ephy_web_application_delete (app_id, NULL);
 }
 
 static char *
@@ -713,15 +710,6 @@ reader_request_cb (WebKitURISchemeRequest *request,
   ephy_reader_handler_handle_request (priv->reader_handler, request);
 }
 
-static void
-pdf_request_cb (WebKitURISchemeRequest *request,
-                EphyEmbedShell         *shell)
-{
-  EphyEmbedShellPrivate *priv = ephy_embed_shell_get_instance_private (shell);
-
-  ephy_pdf_handler_handle_request (priv->pdf_handler, request);
-}
-
 static void
 ephy_resource_request_cb (WebKitURISchemeRequest *request)
 {
@@ -741,7 +729,7 @@ ephy_resource_request_cb (WebKitURISchemeRequest *request)
   request_view = webkit_uri_scheme_request_get_web_view (request);
   uri = webkit_web_view_get_uri (request_view);
 
-  /* ephy-resource:// requests bypass CORS in order to allow ephy-pdf:// to
+  /* ephy-resource:// requests bypass CORS in order to allow custom schemes to
    * access ephy-resource://. Accordingly, we need some custom security to
    * prevent websites from directly accessing ephy-resource://.
    *
@@ -751,9 +739,8 @@ ephy_resource_request_cb (WebKitURISchemeRequest *request)
   if (g_str_has_prefix (uri, "ephy-resource:") ||
       g_str_has_prefix (path, "/org/gnome/epiphany/page-icons/") ||
       g_str_has_prefix (path, "/org/gnome/epiphany/page-templates/") ||
-      (g_str_has_prefix (uri, "ephy-pdf:") && g_str_has_prefix (path, "/org/gnome/epiphany/pdfjs/")) ||
       (g_str_has_prefix (uri, "ephy-reader:") && g_str_has_prefix (path, "/org/gnome/epiphany/readability/")) ||
-      (g_str_has_prefix (uri, "ephy-source:") && g_str_has_prefix (path, "/org/gnome/epiphany/highlightjs/"))) {
+      (g_str_has_prefix (uri, EPHY_VIEW_SOURCE_SCHEME ":") && g_str_has_prefix (path, "/org/gnome/epiphany/highlightjs/"))) {
     stream = g_resources_open_stream (path, 0, &error);
     if (stream)
       webkit_uri_scheme_request_finish (request, stream, size, NULL);
@@ -783,11 +770,13 @@ initialize_web_process_extensions (WebKitWebContext *web_context,
 #endif
 
   private_profile = priv->mode == EPHY_EMBED_SHELL_MODE_PRIVATE || priv->mode == EPHY_EMBED_SHELL_MODE_INCOGNITO || priv->mode == EPHY_EMBED_SHELL_MODE_AUTOMATION;
-  user_data = g_variant_new ("(smsbb)",
+  user_data = g_variant_new ("(smsbbbs)",
                              priv->guid,
                              ephy_profile_dir_is_default () ? NULL : ephy_profile_dir (),
                              g_settings_get_boolean (EPHY_SETTINGS_WEB, EPHY_PREFS_WEB_REMEMBER_PASSWORDS),
-                             private_profile);
+                             private_profile,
+                             FALSE /* is_webextension */,
+                             "" /* webextension_translations */);
   webkit_web_context_set_web_extensions_initialization_user_data (web_context, g_steal_pointer (&user_data));
 }
 
@@ -842,7 +831,6 @@ download_started_cb (WebKitWebContext *web_context,
   EphyEmbedShellPrivate *priv = ephy_embed_shell_get_instance_private (shell);
   g_autoptr (EphyDownload) ephy_download = NULL;
   gboolean ephy_download_set;
-  WebKitWebView *web_view;
 
   /* Is download locked down? */
   if (g_settings_get_boolean (EPHY_SETTINGS_LOCKDOWN,
@@ -861,14 +849,7 @@ download_started_cb (WebKitWebContext *web_context,
     return;
 
   ephy_download = ephy_download_new (download);
-
-  web_view = webkit_download_get_web_view (download);
-  if (EPHY_IS_WEB_VIEW (web_view)) {
-    if (ephy_web_view_get_document_type (EPHY_WEB_VIEW (web_view)) != EPHY_WEB_VIEW_DOCUMENT_PDF)
-      ephy_downloads_manager_add_download (priv->downloads_manager, ephy_download);
-  } else {
-    ephy_downloads_manager_add_download (priv->downloads_manager, ephy_download);
-  }
+  ephy_downloads_manager_add_download (priv->downloads_manager, ephy_download);
 }
 
 static void
@@ -978,11 +959,6 @@ ephy_embed_shell_startup (GApplication *application)
   webkit_web_context_register_uri_scheme (priv->web_context, EPHY_VIEW_SOURCE_SCHEME,
                                           (WebKitURISchemeRequestCallback)source_request_cb,
                                           shell, NULL);
-  /* pdf handler */
-  priv->pdf_handler = ephy_pdf_handler_new ();
-  webkit_web_context_register_uri_scheme (priv->web_context, EPHY_PDF_SCHEME,
-                                          (WebKitURISchemeRequestCallback)pdf_request_cb,
-                                          shell, NULL);
 
   /* reader mode handler */
   priv->reader_handler = ephy_reader_handler_new ();
@@ -1533,12 +1509,3 @@ ephy_embed_shell_unregister_ucm_handler (EphyEmbedShell           *shell,
                                                                           "passwordManagerSave",
                                                                           priv->guid);
 }
-
-void
-ephy_embed_shell_pdf_handler_stop (EphyEmbedShell *shell,
-                                   WebKitWebView  *web_view)
-{
-  EphyEmbedShellPrivate *priv = ephy_embed_shell_get_instance_private (shell);
-
-  ephy_pdf_handler_stop (priv->pdf_handler, web_view);
-}
