@@ -49,8 +49,6 @@ struct _EphyFindToolbar {
   guint find_again_source_id;
   guint find_source_id;
   char *find_string;
-  gboolean links_only;
-  gboolean typing_ahead;
 };
 
 G_DEFINE_TYPE (EphyFindToolbar, ephy_find_toolbar, GTK_TYPE_BIN)
@@ -226,13 +224,6 @@ update_find_string (EphyFindToolbar *toolbar)
   g_source_set_name_by_id (toolbar->find_source_id, "[epiphany] do_search");
 }
 
-static gboolean
-ephy_find_toolbar_activate_link (EphyFindToolbar *toolbar,
-                                 GdkModifierType  mask)
-{
-  return FALSE;
-}
-
 static gboolean
 entry_key_press_event_cb (GtkEntry        *entry,
                           GdkEventKey     *event,
@@ -252,11 +243,6 @@ entry_key_press_event_cb (GtkEntry        *entry,
         handled = FALSE;
         break;
     }
-  } else if ((event->state & mask) == GDK_CONTROL_MASK &&
-             (event->keyval == GDK_KEY_Return ||
-              event->keyval == GDK_KEY_KP_Enter ||
-              event->keyval == GDK_KEY_ISO_Enter)) {
-    handled = ephy_find_toolbar_activate_link (toolbar, event->state);
   } else if ((event->state & mask) == GDK_CONTROL_MASK &&
              (gdk_keyval_to_lower (event->keyval) == GDK_KEY_g)) {
     handled = TRUE;
@@ -276,17 +262,6 @@ entry_key_press_event_cb (GtkEntry        *entry,
   return handled;
 }
 
-static void
-entry_activate_cb (GtkWidget       *entry,
-                   EphyFindToolbar *toolbar)
-{
-  if (toolbar->typing_ahead) {
-    ephy_find_toolbar_activate_link (toolbar, 0);
-  } else {
-    ephy_find_toolbar_find_next (toolbar);
-  }
-}
-
 static void
 ephy_find_toolbar_grab_focus (GtkWidget *widget)
 {
@@ -416,8 +391,8 @@ ephy_find_toolbar_init (EphyFindToolbar *toolbar)
                     G_CALLBACK (entry_key_press_event_cb), toolbar);
   g_signal_connect_after (toolbar->entry, "changed",
                           G_CALLBACK (search_entry_changed_cb), toolbar);
-  g_signal_connect (toolbar->entry, "activate",
-                    G_CALLBACK (entry_activate_cb), toolbar);
+  g_signal_connect_swapped (toolbar->entry, "activate",
+                            G_CALLBACK (ephy_find_toolbar_find_next), toolbar);
   g_signal_connect_swapped (toolbar->next, "clicked",
                             G_CALLBACK (ephy_find_toolbar_find_next), toolbar);
   g_signal_connect_swapped (toolbar->prev, "clicked",
@@ -437,20 +412,13 @@ ephy_find_toolbar_dispose (GObject *object)
 {
   EphyFindToolbar *toolbar = EPHY_FIND_TOOLBAR (object);
 
-  if (toolbar->find_again_source_id != 0) {
-    g_source_remove (toolbar->find_again_source_id);
-    toolbar->find_again_source_id = 0;
-  }
+  g_clear_handle_id (&toolbar->find_again_source_id, g_source_remove);
+  g_clear_handle_id (&toolbar->find_source_id, g_source_remove);
 
-  if (toolbar->find_source_id != 0) {
-    g_source_remove (toolbar->find_source_id);
-    toolbar->find_source_id = 0;
-  }
+  g_cancellable_cancel (toolbar->cancellable);
+  g_clear_object (&toolbar->cancellable);
 
-  if (toolbar->cancellable) {
-    g_cancellable_cancel (toolbar->cancellable);
-    g_clear_object (&toolbar->cancellable);
-  }
+  g_clear_object (&toolbar->entry_tag);
 
   G_OBJECT_CLASS (ephy_find_toolbar_parent_class)->dispose (object);
 }
@@ -646,15 +614,10 @@ ephy_find_toolbar_selection_async (GObject      *source_object,
 }
 
 void
-ephy_find_toolbar_open (EphyFindToolbar *toolbar,
-                        gboolean         links_only,
-                        gboolean         typing_ahead)
+ephy_find_toolbar_open (EphyFindToolbar *toolbar)
 {
   g_assert (toolbar->web_view != NULL);
 
-  toolbar->typing_ahead = typing_ahead;
-  toolbar->links_only = links_only;
-
   webkit_web_view_run_javascript (toolbar->web_view, "window.getSelection().toString();", toolbar->cancellable, ephy_find_toolbar_selection_async, toolbar);
 
   gtk_editable_select_region (GTK_EDITABLE (toolbar->entry), 0, -1);
