@@ -40,6 +40,7 @@
 #include <glib/gi18n.h>
 #include <glib/gstdio.h>
 #include <gtk/gtk.h>
+#include <libportal/portal-helpers.h>
 #include <libxml/xmlreader.h>
 #include <stdlib.h>
 #include <string.h>
@@ -67,13 +68,14 @@ typedef enum {
 static GHashTable *files;
 static GHashTable *mime_table;
 
-static gboolean keep_directory;
 static char *profile_dir_global;
 static char *cache_dir;
 static char *config_dir;
 static char *tmp_dir;
 static EphyProfileDirType profile_dir_type;
 
+static XdpPortal *global_portal;
+
 GQuark ephy_file_helpers_error_quark;
 
 /**
@@ -175,6 +177,40 @@ ephy_file_desktop_dir (void)
   return g_build_filename (g_get_home_dir (), _("Desktop"), NULL);
 }
 
+char *
+ephy_file_get_display_name (GFile *file)
+{
+  g_autofree char *path = NULL;
+  g_autoptr (GFileInfo) info = NULL;
+  g_autoptr (GError) error = NULL;
+
+  path = g_file_get_path (file);
+
+  if (!g_strcmp0 (path, g_get_home_dir ()))
+    return g_strdup (_("Home"));
+
+  if (!g_strcmp0 (path, ephy_file_desktop_dir ()))
+    return g_strdup (_("Desktop"));
+
+  if (!g_strcmp0 (path, ephy_file_download_dir ()))
+    return g_strdup (_("Downloads"));
+
+  info =
+    g_file_query_info (file,
+                       G_FILE_ATTRIBUTE_STANDARD_DISPLAY_NAME,
+                       G_FILE_QUERY_INFO_NONE,
+                       NULL,
+                       &error);
+
+  if (error) {
+    g_warning ("Failed to query display name for %s: %s", path, error->message);
+
+    return g_file_get_basename (file);
+  }
+
+  return g_strdup (g_file_info_get_display_name (info));
+}
+
 /**
  * ephy_file_tmp_filename:
  * @base: the base name of the temp file to create, containing "XXXXXX"
@@ -361,7 +397,6 @@ ephy_file_helpers_init (const char            *profile_dir,
                                  (GDestroyNotify)g_free,
                                  (GDestroyNotify)g_free);
 
-  keep_directory = flags & EPHY_FILE_HELPERS_KEEP_DIR;
   private_profile = (flags & EPHY_FILE_HELPERS_PRIVATE_PROFILE || flags & EPHY_FILE_HELPERS_TESTING_MODE);
   steal_data_from_profile = flags & EPHY_FILE_HELPERS_STEAL_DATA;
 
@@ -455,6 +490,8 @@ ephy_file_helpers_init (const char            *profile_dir,
     }
   }
 
+  global_portal = xdp_portal_new ();
+
   return ret;
 }
 
@@ -479,16 +516,12 @@ ephy_file_helpers_shutdown (void)
   g_clear_pointer (&config_dir, g_free);
 
   if (tmp_dir != NULL) {
-    if (!keep_directory) {
-      /* recursively delete the contents and the
-       * directory */
-      LOG ("shutdown: delete tmp_dir %s", tmp_dir);
-      ephy_file_delete_dir_recursively (tmp_dir, NULL);
-    }
-
-    g_free (tmp_dir);
-    tmp_dir = NULL;
+    LOG ("shutdown: delete tmp_dir %s", tmp_dir);
+    ephy_file_delete_dir_recursively (tmp_dir, NULL);
+    g_clear_pointer (&tmp_dir, g_free);
   }
+
+  g_clear_object (&global_portal);
 }
 
 /**
@@ -542,8 +575,7 @@ ephy_ensure_dir_exists (const char  *dir,
 
 static gboolean
 launch_application (GAppInfo *app,
-                    GList    *files,
-                    guint32   user_time)
+                    GList    *files)
 {
   g_autoptr (GdkAppLaunchContext) context = NULL;
   g_autoptr (GError) error = NULL;
@@ -551,17 +583,11 @@ launch_application (GAppInfo *app,
   GdkScreen *screen;
   gboolean res;
 
-  /* This is impossible to implement inside sandbox. Higher layers must
-   * ensure we don't get here.
-   */
-  g_assert (!ephy_is_running_inside_sandbox ());
-
   display = gdk_display_get_default ();
   screen = gdk_screen_get_default ();
 
   context = gdk_display_get_app_launch_context (display);
   gdk_app_launch_context_set_screen (context, screen);
-  gdk_app_launch_context_set_timestamp (context, user_time);
 
   res = g_app_info_launch (app, files,
                            G_APP_LAUNCH_CONTEXT (context), &error);
@@ -571,33 +597,6 @@ launch_application (GAppInfo *app,
   return res;
 }
 
-/**
- * ephy_file_launch_desktop_file:
- * @filename: the path to the .desktop file
- * @tag: used to guard against improper usage
- *
- * Launches the application described by the desktop file @filename.
- *
- * Returns: %TRUE if the application launch was successful
- **/
-gboolean
-ephy_file_launch_desktop_file (const char                   *filename,
-                               guint32                       user_time,
-                               EphyFileHelpersNotFlatpakTag  tag)
-{
-  g_autoptr (GDesktopAppInfo) app = NULL;
-
-  /* This is impossible to implement inside sandbox. Higher layers must
-   * ensure we don't get here.
-   */
-  g_assert (tag == EPHY_FILE_HELPERS_I_UNDERSTAND_I_MUST_NOT_USE_THIS_FUNCTION_UNDER_FLATPAK);
-  g_assert (!ephy_is_running_inside_sandbox ());
-
-  app = g_desktop_app_info_new (filename);
-
-  return launch_application (G_APP_INFO (app), NULL, user_time);
-}
-
 static gboolean
 launch_via_uri_handler (GFile *file)
 {
@@ -623,7 +622,6 @@ launch_via_uri_handler (GFile *file)
 /**
  * ephy_file_launch_handler:
  * @file: a #GFile to pass as argument
- * @user_time: user time to prevent focus stealing
  *
  * Launches @file with its default handler application, if @mime_type is %NULL
  * then @file will be queried for its type.
@@ -631,8 +629,7 @@ launch_via_uri_handler (GFile *file)
  * Returns: %TRUE on success
  **/
 gboolean
-ephy_file_launch_handler (GFile   *file,
-                          guint32  user_time)
+ephy_file_launch_handler (GFile *file)
 {
   GAppInfo *app = NULL;
   gboolean ret = FALSE;
@@ -656,32 +653,23 @@ ephy_file_launch_handler (GFile   *file,
   }
 
   list = g_list_append (list, file);
-  ret = launch_application (app, list, user_time);
+  ret = launch_application (app, list);
 
   return ret;
 }
 
 static gboolean
-open_in_default_handler (const char                   *uri,
-                         const char                   *mime_type,
-                         guint32                       timestamp,
-                         GdkScreen                    *screen,
-                         EphyFileHelpersNotFlatpakTag  tag)
+open_in_default_handler (const char *uri,
+                         const char *mime_type,
+                         GdkScreen  *screen)
 {
   g_autoptr (GdkAppLaunchContext) context = NULL;
   g_autoptr (GAppInfo) appinfo = NULL;
   g_autoptr (GError) error = NULL;
   GList uris;
 
-  /* This is impossible to implement inside sandbox. Higher layers must
-   * ensure we don't get here.
-   */
-  g_assert (tag == EPHY_FILE_HELPERS_I_UNDERSTAND_I_MUST_NOT_USE_THIS_FUNCTION_UNDER_FLATPAK);
-  g_assert (!ephy_is_running_inside_sandbox ());
-
   context = gdk_display_get_app_launch_context (screen ? gdk_screen_get_display (screen) : gdk_display_get_default ());
   gdk_app_launch_context_set_screen (context, screen);
-  gdk_app_launch_context_set_timestamp (context, timestamp);
 
   appinfo = g_app_info_get_default_for_type (mime_type, TRUE);
   if (!appinfo) {
@@ -701,18 +689,19 @@ open_in_default_handler (const char                   *uri,
 }
 
 gboolean
-ephy_file_open_uri_in_default_browser (const char                   *uri,
-                                       guint32                       user_time,
-                                       GdkScreen                    *screen,
-                                       EphyFileHelpersNotFlatpakTag  tag)
+ephy_file_open_uri_in_default_browser (const char *uri,
+                                       GdkScreen  *screen)
 {
-  return open_in_default_handler (uri, "x-scheme-handler/http", user_time, screen, tag);
+  if (ephy_is_running_inside_sandbox ()) {
+    ephy_open_uri_via_flatpak_portal (uri);
+    return TRUE;
+  }
+  return open_in_default_handler (uri, "x-scheme-handler/http", screen);
 }
 
 /**
  * ephy_file_browse_to:
  * @file: a #GFile
- * @user_time: user_time to prevent focus stealing
  *
  * Launches the default application for browsing directories to point to
  * @file. E.g. nautilus will jump to @file within its directory and
@@ -721,8 +710,7 @@ ephy_file_open_uri_in_default_browser (const char                   *uri,
  * Returns: %TRUE if the launch succeeded
  **/
 gboolean
-ephy_file_browse_to (GFile   *file,
-                     guint32  user_time)
+ephy_file_browse_to (GFile *file)
 {
   g_autofree char *uri = g_file_get_uri (file);
 
@@ -731,7 +719,7 @@ ephy_file_browse_to (GFile   *file,
     return TRUE;
   }
 
-  return open_in_default_handler (uri, "inode/directory", user_time, NULL, EPHY_FILE_HELPERS_I_UNDERSTAND_I_MUST_NOT_USE_THIS_FUNCTION_UNDER_FLATPAK);
+  return open_in_default_handler (uri, "inode/directory", NULL);
 }
 
 /**
@@ -904,5 +892,13 @@ ephy_copy_directory (const char *source,
         return;
       }
     }
+  } else {
+    g_warning ("Copying the file type of %s isn't supported.", source);
   }
 }
+
+XdpPortal *
+ephy_get_portal (void)
+{
+  return global_portal;
+}
