@@ -27,9 +27,9 @@
 struct _EphyHistoryRecord {
   GObject parent_instance;
 
-  char      *id;
-  char      *title;
-  char      *uri;
+  char *id;
+  char *title;
+  char *uri;
   GSequence *visits;
 };
 
@@ -64,7 +64,7 @@ ephy_history_record_visit_new (gint64 timestamp,
 {
   EphyHistoryRecordVisit *visit;
 
-  visit = g_slice_new (EphyHistoryRecordVisit);
+  visit = g_new (EphyHistoryRecordVisit, 1);
   visit->timestamp = timestamp;
   visit->type = type;
 
@@ -76,7 +76,7 @@ ephy_history_record_visit_free (EphyHistoryRecordVisit *visit)
 {
   g_assert (visit);
 
-  g_slice_free (EphyHistoryRecordVisit, visit);
+  g_free (visit);
 }
 
 static int
@@ -102,15 +102,15 @@ ephy_history_record_set_property (GObject      *object,
   switch (prop_id) {
     case PROP_ID:
       g_free (self->id);
-      self->id = g_strdup (g_value_get_string (value));
+      self->id = g_value_dup_string (value);
       break;
     case PROP_TITLE:
       g_free (self->title);
-      self->title = g_strdup (g_value_get_string (value));
+      self->title = g_value_dup_string (value);
       break;
     case PROP_URI:
       g_free (self->uri);
-      self->uri = g_strdup (g_value_get_string (value));
+      self->uri = g_value_dup_string (value);
       break;
     case PROP_VISITS:
       if (self->visits)
