@@ -383,13 +383,15 @@ secret_password_store_cb (GObject               *source_object,
 
   secret_password_store_finish (result, &error);
   if (error) {
-    g_warning ("Failed to store password record for (%s, %s, %s, %s, %s): %s",
-               origin,
-               ephy_password_record_get_target_origin (data->record),
-               username,
-               ephy_password_record_get_username_field (data->record),
-               ephy_password_record_get_password_field (data->record),
-               error->message);
+    if (!g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED)) {
+      g_warning ("Failed to store password record for (%s, %s, %s, %s, %s): %s",
+                 origin,
+                 ephy_password_record_get_target_origin (data->record),
+                 username,
+                 ephy_password_record_get_username_field (data->record),
+                 ephy_password_record_get_password_field (data->record),
+                 error->message);
+    }
     g_error_free (error);
   } else {
     ephy_password_manager_cache_add (data->manager, origin, username);
@@ -578,7 +580,8 @@ retrieve_secret_cb (GObject        *source_object,
 
   value = secret_retrievable_retrieve_secret_finish (retrievable, result, &error);
   if (!value) {
-    g_warning ("Failed to retrieve password: %s", error->message);
+    if (!g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED))
+      g_warning ("Failed to retrieve password: %s", error->message);
     g_error_free (error);
     goto out;
   }
@@ -639,7 +642,8 @@ secret_password_search_cb (GObject        *source_object,
   matches = secret_password_search_finish (result, &error);
   if (!matches) {
     if (error) {
-      g_warning ("Failed to search secrets in password schema: %s", error->message);
+      if (!g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED))
+        g_warning ("Failed to search secrets in password schema: %s", error->message);
       g_error_free (error);
     }
     if (data->callback)
@@ -800,14 +804,11 @@ forget_cb (GList    *records,
   EphyPasswordManager *self = EPHY_PASSWORD_MANAGER (g_task_get_source_object (task));
   EphyPasswordRecord *record;
 
-  /* We expect only one matching record here. */
-  if (g_list_length (records) == 1) {
-    record = EPHY_PASSWORD_RECORD (records->data);
-    g_signal_emit_by_name (self, "synchronizable-deleted", record);
-    ephy_password_manager_forget_record (self, record, NULL, task);
-  } else {
-    g_warn_if_reached ();
-  }
+  g_assert (g_list_length (records) == 1);
+
+  record = EPHY_PASSWORD_RECORD (records->data);
+  g_signal_emit_by_name (self, "synchronizable-deleted", record);
+  ephy_password_manager_forget_record (self, record, NULL, task);
 }
 
 gboolean
@@ -937,12 +938,9 @@ replace_existing_cb (GList    *records,
 {
   ManageRecordAsyncData *data = (ManageRecordAsyncData *)user_data;
 
-  /* We expect only one matching record here. */
-  if (g_list_length (records) == 1)
-    ephy_password_manager_forget_record (data->manager, records->data, data->record, NULL);
-  else
-    g_warn_if_reached ();
+  g_assert (g_list_length (records) == 1);
 
+  ephy_password_manager_forget_record (data->manager, records->data, data->record, NULL);
   manage_record_async_data_free (data);
 }
 
