@@ -26,7 +26,6 @@
 #define GCR_API_SUBJECT_TO_CHANGE
 #include <gcr/gcr.h>
 #include <glib/gi18n.h>
-#include <libsoup/soup.h>
 
 /**
  * SECTION:ephy-certificate-dialog
@@ -63,11 +62,10 @@ static void
 ephy_certificate_dialog_set_address (EphyCertificateDialog *dialog,
                                      const char            *address)
 {
-  SoupURI *uri;
+  g_autoptr (GUri) uri = NULL;
 
-  uri = soup_uri_new (address);
-  gtk_window_set_title (GTK_WINDOW (dialog), uri->host);
-  soup_uri_free (uri);
+  uri = g_uri_parse (address, G_URI_FLAGS_NONE, NULL);
+  gtk_window_set_title (GTK_WINDOW (dialog), g_uri_get_host (uri));
 }
 
 static void
@@ -85,10 +83,11 @@ ephy_certificate_dialog_set_certificate (EphyCertificateDialog *dialog,
   g_byte_array_unref (certificate_data);
 
   certificate_widget = GTK_WIDGET (gcr_certificate_widget_new (simple_certificate));
+  gtk_widget_set_vexpand (certificate_widget, TRUE);
   g_object_unref (simple_certificate);
 
   content_area = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
-  gtk_box_pack_start (GTK_BOX (content_area), certificate_widget, TRUE, TRUE, 0);
+  gtk_box_pack_start (GTK_BOX (content_area), certificate_widget, FALSE, TRUE, 0);
   gtk_widget_show (certificate_widget);
 }
 
@@ -284,7 +283,6 @@ ephy_certificate_dialog_init (EphyCertificateDialog *dialog)
 
   gtk_window_set_default_size (GTK_WINDOW (dialog), -1, 500);
 
-  gtk_container_set_border_width (GTK_CONTAINER (dialog), 10);
   gtk_window_set_skip_taskbar_hint (GTK_WINDOW (dialog), TRUE);
 
   grid = gtk_grid_new ();
@@ -292,8 +290,6 @@ ephy_certificate_dialog_init (EphyCertificateDialog *dialog)
   gtk_grid_set_column_spacing (GTK_GRID (grid), 12);
 
   dialog->icon = gtk_image_new ();
-  gtk_widget_set_halign (dialog->icon, GTK_ALIGN_CENTER);
-  gtk_widget_set_valign (dialog->icon, GTK_ALIGN_START);
   gtk_grid_attach (GTK_GRID (grid), dialog->icon,
                    0, 0, 1, 2);
   gtk_widget_show (dialog->icon);
@@ -302,8 +298,6 @@ ephy_certificate_dialog_init (EphyCertificateDialog *dialog)
   gtk_label_set_use_markup (GTK_LABEL (dialog->title), TRUE);
   gtk_label_set_line_wrap (GTK_LABEL (dialog->title), TRUE);
   gtk_label_set_selectable (GTK_LABEL (dialog->title), TRUE);
-  gtk_widget_set_halign (dialog->title, GTK_ALIGN_START);
-  gtk_widget_set_valign (dialog->title, GTK_ALIGN_CENTER);
   gtk_label_set_xalign (GTK_LABEL (dialog->title), 0.0);
   gtk_grid_attach_next_to (GTK_GRID (grid), dialog->title,
                            dialog->icon, GTK_POS_RIGHT,
@@ -313,8 +307,6 @@ ephy_certificate_dialog_init (EphyCertificateDialog *dialog)
   dialog->text = gtk_label_new (NULL);
   gtk_label_set_line_wrap (GTK_LABEL (dialog->text), TRUE);
   gtk_label_set_selectable (GTK_LABEL (dialog->text), TRUE);
-  gtk_widget_set_halign (dialog->text, GTK_ALIGN_START);
-  gtk_widget_set_valign (dialog->text, GTK_ALIGN_START);
   gtk_label_set_xalign (GTK_LABEL (dialog->text), 0.0);
   gtk_label_set_yalign (GTK_LABEL (dialog->text), 0.0);
   gtk_grid_attach_next_to (GTK_GRID (grid), dialog->text,
@@ -323,7 +315,11 @@ ephy_certificate_dialog_init (EphyCertificateDialog *dialog)
 
   content_area = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
   gtk_box_set_spacing (GTK_BOX (content_area), 14);
-  gtk_box_pack_start (GTK_BOX (content_area), grid, FALSE, FALSE, 0);
+  gtk_widget_set_margin_top (content_area, 10);
+  gtk_widget_set_margin_bottom (content_area, 10);
+  gtk_widget_set_margin_start (content_area, 10);
+  gtk_widget_set_margin_end (content_area, 10);
+  gtk_box_pack_start (GTK_BOX (content_area), grid, FALSE, TRUE, 0);
   gtk_widget_show (grid);
 }
 
