@@ -272,8 +272,7 @@ widget_action_button_clicked_cb (EphyDownloadWidget *widget)
     ephy_downloads_manager_remove_download (manager, widget->download);
   } else {
     ephy_download_do_download_action (widget->download,
-                                      EPHY_DOWNLOAD_ACTION_BROWSE_TO,
-                                      gtk_get_current_event_time ());
+                                      EPHY_DOWNLOAD_ACTION_BROWSE_TO);
   }
 }
 
