@@ -57,14 +57,10 @@ void            ephy_location_entry_set_lock_tooltip           (EphyLocationEntr
 void            ephy_location_entry_set_add_bookmark_popover   (EphyLocationEntry *entry,
                                                                 GtkPopover        *popover);
 
-GtkPopover     *ephy_location_entry_get_add_bookmark_popover   (EphyLocationEntry *entry);
+void            ephy_location_entry_show_add_bookmark_popover  (EphyLocationEntry *entry);
 
 GtkWidget      *ephy_location_entry_get_entry                  (EphyLocationEntry *entry);
 
-GtkWidget      *ephy_location_entry_get_bookmark_widget        (EphyLocationEntry *entry);
-
-GtkWidget      *ephy_location_entry_get_reader_mode_widget     (EphyLocationEntry *entry);
-
 void            ephy_location_entry_set_reader_mode_visible    (EphyLocationEntry *entry,
                                                                 gboolean           visible);
 
@@ -82,6 +78,6 @@ void            ephy_location_entry_page_action_add            (EphyLocationEntr
 void            ephy_location_entry_page_action_clear          (EphyLocationEntry *entry);
 
 void            ephy_location_entry_set_adaptive_mode          (EphyLocationEntry *entry,
-                                                                EphyAdaptiveMode   adpative_mode);
+                                                                EphyAdaptiveMode   adaptive_mode);
 
 G_END_DECLS
