@@ -20,11 +20,12 @@
 
 #include "config.h"
 
-#include "ephy-bookmark-properties-grid.h"
+#include "ephy-bookmark-properties.h"
 #include "ephy-bookmark-row.h"
 #include "ephy-embed-prefs.h"
 #include "ephy-embed-shell.h"
 #include "ephy-favicon-helpers.h"
+#include "ephy-settings.h"
 
 struct _EphyBookmarkRow {
   GtkListBoxRow parent_instance;
@@ -66,11 +67,11 @@ ephy_bookmark_row_button_clicked_cb (EphyBookmarkRow *row,
 
   content_area = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
 
-  grid = ephy_bookmark_properties_grid_new (ephy_bookmark_row_get_bookmark (row),
-                                            EPHY_BOOKMARK_PROPERTIES_GRID_TYPE_DIALOG,
-                                            dialog);
+  grid = ephy_bookmark_properties_new (ephy_bookmark_row_get_bookmark (row),
+                                       EPHY_BOOKMARK_PROPERTIES_TYPE_DIALOG,
+                                       dialog);
   gtk_window_set_default (GTK_WINDOW (dialog),
-                          ephy_bookmark_properties_grid_get_add_tag_button (EPHY_BOOKMARK_PROPERTIES_GRID (grid)));
+                          ephy_bookmark_properties_get_add_tag_button (EPHY_BOOKMARK_PROPERTIES (grid)));
 
   gtk_container_add (GTK_CONTAINER (content_area), grid);
 
@@ -91,13 +92,15 @@ ephy_bookmark_row_favicon_loaded_cb (GObject      *source,
 
   icon_surface = webkit_favicon_database_get_favicon_finish (database, result, NULL);
   if (icon_surface) {
-    favicon = ephy_pixbuf_get_from_surface_scaled (icon_surface, FAVICON_SIZE, FAVICON_SIZE);
+    int scale = gtk_widget_get_scale_factor (self->favicon_image);
+
+    favicon = ephy_pixbuf_get_from_surface_scaled (icon_surface, FAVICON_SIZE * scale, FAVICON_SIZE * scale);
     cairo_surface_destroy (icon_surface);
   }
 
   if (favicon) {
     if (self->favicon_image != NULL)
-      gtk_image_set_from_pixbuf (GTK_IMAGE (self->favicon_image), favicon);
+      gtk_image_set_from_gicon (GTK_IMAGE (self->favicon_image), G_ICON (favicon), GTK_ICON_SIZE_BUTTON);
   }
 }
 
@@ -158,6 +161,7 @@ transform_bookmark_title (GBinding     *binding,
                           GValue       *to_value,
                           gpointer      user_data)
 {
+  EphyBookmarkRow *row = EPHY_BOOKMARK_ROW (user_data);
   const char *title;
 
   title = g_value_get_string (from_value);
@@ -166,12 +170,14 @@ transform_bookmark_title (GBinding     *binding,
     EphyBookmark *bookmark;
     const char *url;
 
-    bookmark = EPHY_BOOKMARK (user_data);
+    bookmark = EPHY_BOOKMARK (row->bookmark);
     url = ephy_bookmark_get_url (bookmark);
 
     g_value_set_string (to_value, url);
+    gtk_widget_set_tooltip_text (GTK_WIDGET (row), url);
   } else {
     g_value_set_string (to_value, title);
+    gtk_widget_set_tooltip_text (GTK_WIDGET (row), title);
   }
 
   return TRUE;
@@ -191,7 +197,13 @@ ephy_bookmark_row_constructed (GObject *object)
                                G_BINDING_SYNC_CREATE,
                                transform_bookmark_title,
                                NULL,
-                               self->bookmark, NULL);
+                               self, NULL);
+
+  g_settings_bind (EPHY_SETTINGS_LOCKDOWN,
+                   EPHY_PREFS_LOCKDOWN_BOOKMARK_EDITING,
+                   self->properties_button,
+                   "visible",
+                   G_SETTINGS_BIND_INVERT_BOOLEAN);
 
   database = webkit_web_context_get_favicon_database (ephy_embed_shell_get_web_context (shell));
   webkit_favicon_database_get_favicon (database,
