@@ -23,7 +23,6 @@
 #include "ephy-add-bookmark-popover.h"
 #include "ephy-desktop-utils.h"
 #include "ephy-downloads-popover.h"
-#include "ephy-downloads-progress-icon.h"
 #include "ephy-location-entry.h"
 #include "ephy-shell.h"
 #include "ephy-window.h"
@@ -258,25 +257,12 @@ ephy_action_bar_end_class_init (EphyActionBarEndClass *klass)
                                         browser_action_box);
 }
 
-static void
-add_bookmark_button_clicked_cb (EphyActionBarEnd *action_bar_end)
-{
-  GtkWidget *window = gtk_widget_get_toplevel (GTK_WIDGET (action_bar_end->bookmark_button));
-  GtkWidget *popover = ephy_add_bookmark_popover_new (GTK_WIDGET (action_bar_end->bookmark_button), window);
-
-  g_signal_connect_object (popover, "update-state", G_CALLBACK (ephy_window_sync_bookmark_state), action_bar_end, G_CONNECT_SWAPPED);
-
-  ephy_add_bookmark_popover_show (EPHY_ADD_BOOKMARK_POPOVER (popover));
-}
-
 static void
 ephy_action_bar_end_init (EphyActionBarEnd *action_bar_end)
 {
   GObject *object = G_OBJECT (action_bar_end);
   EphyDownloadsManager *downloads_manager;
-
-  /* Ensure the types used by the template have been initialized. */
-  EPHY_TYPE_DOWNLOADS_PROGRESS_ICON;
+  GtkWidget *popover;
 
   gtk_widget_init_template (GTK_WIDGET (action_bar_end));
 
@@ -318,9 +304,9 @@ ephy_action_bar_end_init (EphyActionBarEnd *action_bar_end)
                            G_CALLBACK (show_downloads_cb),
                            object, 0);
 
-  g_signal_connect_object (action_bar_end->bookmark_button, "clicked",
-                           G_CALLBACK (add_bookmark_button_clicked_cb), action_bar_end,
-                           G_CONNECT_SWAPPED);
+  popover = ephy_add_bookmark_popover_new ();
+
+  gtk_menu_button_set_popover (GTK_MENU_BUTTON (action_bar_end->bookmark_button), popover);
 }
 
 EphyActionBarEnd *
@@ -391,13 +377,13 @@ ephy_action_bar_end_set_bookmark_icon_state (EphyActionBarEnd      *action_bar_e
     case EPHY_BOOKMARK_ICON_EMPTY:
       gtk_widget_set_visible (action_bar_end->bookmark_button, TRUE);
       gtk_image_set_from_icon_name (GTK_IMAGE (action_bar_end->bookmark_image),
-                                    "non-starred-symbolic",
+                                    "ephy-non-starred-symbolic",
                                     GTK_ICON_SIZE_BUTTON);
       break;
     case EPHY_BOOKMARK_ICON_BOOKMARKED:
       gtk_widget_set_visible (action_bar_end->bookmark_button, TRUE);
       gtk_image_set_from_icon_name (GTK_IMAGE (action_bar_end->bookmark_image),
-                                    "starred-symbolic",
+                                    "ephy-starred-symbolic",
                                     GTK_ICON_SIZE_BUTTON);
       break;
     default:
