@@ -233,9 +233,12 @@ void
 ephy_action_bar_set_adaptive_mode (EphyActionBar    *action_bar,
                                    EphyAdaptiveMode  adaptive_mode)
 {
+  EphyEmbedShellMode mode = ephy_embed_shell_get_mode (ephy_embed_shell_get_default ());
+
   action_bar->adaptive_mode = adaptive_mode;
   ephy_action_bar_end_set_show_bookmark_button (action_bar->action_bar_end,
-                                                adaptive_mode == EPHY_ADAPTIVE_MODE_NARROW);
+                                                adaptive_mode == EPHY_ADAPTIVE_MODE_NARROW &&
+                                                mode != EPHY_EMBED_SHELL_MODE_APPLICATION);
 
   update_revealer (action_bar);
 }
