@@ -29,7 +29,6 @@
 #include "ephy-file-helpers.h"
 #include "ephy-flatpak-utils.h"
 #include "ephy-location-entry.h"
-#include "ephy-notebook.h"
 #include "ephy-settings.h"
 #include "ephy-shell.h"
 #include "ephy-title-box.h"
@@ -39,6 +38,8 @@
 #include <glib/gi18n.h>
 #include <handy.h>
 
+#define POPOVER_HIDE_DELAY 300
+
 enum {
   PROP_0,
   PROP_WINDOW,
@@ -51,8 +52,9 @@ static GParamSpec *object_properties[N_PROPERTIES] = { NULL, };
 static const char *REFRESH_BUTTON_TOOLTIP = N_("Reload the current page");
 
 struct _EphyHeaderBar {
-  GtkHeaderBar parent_instance;
+  GtkBin parent_instance;
 
+  GtkWidget *header_bar;
   EphyWindow *window;
   EphyTitleWidget *title_widget;
   GtkRevealer *start_revealer;
@@ -60,13 +62,16 @@ struct _EphyHeaderBar {
   EphyActionBarStart *action_bar_start;
   EphyActionBarEnd *action_bar_end;
   GtkWidget *page_menu_button;
-  GtkWidget *zoom_level_button;
+  GtkWidget *zoom_level_label;
   GtkWidget *restore_button;
   GtkWidget *combined_stop_reload_button;
   GtkWidget *combined_stop_reload_image;
+  GtkWidget *page_menu_popover;
+
+  guint popover_hide_timeout_id;
 };
 
-G_DEFINE_TYPE (EphyHeaderBar, ephy_header_bar, GTK_TYPE_HEADER_BAR)
+G_DEFINE_TYPE (EphyHeaderBar, ephy_header_bar, GTK_TYPE_BIN)
 
 static void
 ephy_header_bar_set_property (GObject      *object,
@@ -117,6 +122,16 @@ sync_chromes_visibility (EphyHeaderBar *header_bar)
   gtk_widget_set_visible (header_bar->page_menu_button, chrome & EPHY_WINDOW_CHROME_MENU);
 }
 
+static gboolean
+hide_timeout_cb (EphyHeaderBar *header_bar)
+{
+  gtk_popover_popdown (GTK_POPOVER (header_bar->page_menu_popover));
+
+  header_bar->popover_hide_timeout_id = 0;
+
+  return G_SOURCE_REMOVE;
+}
+
 void
 fullscreen_changed_cb (EphyHeaderBar *header_bar)
 {
@@ -124,36 +139,15 @@ fullscreen_changed_cb (EphyHeaderBar *header_bar)
 
   g_object_get (header_bar->window, "fullscreen", &fullscreen, NULL);
 
-  gtk_header_bar_set_show_close_button (GTK_HEADER_BAR (header_bar), !fullscreen);
+  gtk_header_bar_set_show_close_button (GTK_HEADER_BAR (header_bar->header_bar), !fullscreen);
   gtk_widget_set_visible (header_bar->restore_button, fullscreen);
-  ephy_action_bar_set_is_fullscreen (header_bar->action_bar_start, fullscreen);
-}
 
-static void
-add_bookmark_button_clicked_cb (EphyLocationEntry *entry,
-                                gpointer          *user_data)
-{
-  EphyHeaderBar *header_bar = EPHY_HEADER_BAR (user_data);
-  GActionGroup *action_group;
-  GAction *action;
+  if (fullscreen) {
+    g_clear_handle_id (&header_bar->popover_hide_timeout_id, g_source_remove);
 
-  action_group = gtk_widget_get_action_group (GTK_WIDGET (header_bar->window), "win");
-  action = g_action_map_lookup_action (G_ACTION_MAP (action_group), "bookmark-page");
-
-  g_action_activate (action, NULL);
-}
-
-static void
-restore_button_clicked_cb (GtkButton     *button,
-                           EphyHeaderBar *header_bar)
-{
-  GActionGroup *action_group;
-  GAction *action;
-
-  action_group = gtk_widget_get_action_group (GTK_WIDGET (header_bar->window), "win");
-  action = g_action_map_lookup_action (G_ACTION_MAP (action_group), "fullscreen");
-
-  g_action_activate (action, NULL);
+    header_bar->popover_hide_timeout_id =
+      g_timeout_add (POPOVER_HIDE_DELAY, (GSourceFunc)hide_timeout_cb, header_bar);
+  }
 }
 
 static void
@@ -169,7 +163,6 @@ ephy_header_bar_constructed (GObject *object)
 {
   EphyHeaderBar *header_bar = EPHY_HEADER_BAR (object);
   GtkWidget *button;
-  GtkWidget *page_menu_popover;
   GtkWidget *event_box;
   GtkBuilder *builder;
   EphyEmbedShell *embed_shell;
@@ -184,6 +177,12 @@ ephy_header_bar_constructed (GObject *object)
                            G_CALLBACK (fullscreen_changed_cb), header_bar,
                            G_CONNECT_SWAPPED);
 
+  /* Header bar */
+  header_bar->header_bar = gtk_header_bar_new ();
+  gtk_header_bar_set_show_close_button (GTK_HEADER_BAR (header_bar->header_bar), TRUE);
+  gtk_widget_show (header_bar->header_bar);
+  gtk_container_add (GTK_CONTAINER (header_bar), header_bar->header_bar);
+
   /* Start action elements */
   header_bar->action_bar_start = ephy_action_bar_start_new ();
   gtk_widget_show (GTK_WIDGET (header_bar->action_bar_start));
@@ -195,7 +194,7 @@ ephy_header_bar_constructed (GObject *object)
   gtk_revealer_set_transition_type (GTK_REVEALER (header_bar->start_revealer), GTK_REVEALER_TRANSITION_TYPE_SLIDE_RIGHT);
   gtk_container_add (GTK_CONTAINER (header_bar->start_revealer), GTK_WIDGET (header_bar->action_bar_start));
 
-  gtk_header_bar_pack_start (GTK_HEADER_BAR (header_bar),
+  gtk_header_bar_pack_start (GTK_HEADER_BAR (header_bar->header_bar),
                              GTK_WIDGET (header_bar->start_revealer));
 
   embed_shell = ephy_embed_shell_get_default ();
@@ -210,7 +209,7 @@ ephy_header_bar_constructed (GObject *object)
   event_box = gtk_event_box_new ();
   gtk_widget_add_events (event_box, GDK_ALL_EVENTS_MASK);
   gtk_widget_show (event_box);
-  gtk_header_bar_set_custom_title (GTK_HEADER_BAR (header_bar), event_box);
+  gtk_header_bar_set_custom_title (GTK_HEADER_BAR (header_bar->header_bar), event_box);
   gtk_widget_set_name (event_box, "title-box-container");
 
   if (is_desktop_pantheon ()) {
@@ -236,24 +235,18 @@ ephy_header_bar_constructed (GObject *object)
   gtk_widget_show (GTK_WIDGET (header_bar->title_widget));
 
   if (EPHY_IS_LOCATION_ENTRY (header_bar->title_widget)) {
-    ephy_location_entry_set_add_bookmark_popover (EPHY_LOCATION_ENTRY (header_bar->title_widget),
-                                                  GTK_POPOVER (ephy_add_bookmark_popover_new (header_bar)));
+    EphyLocationEntry *lentry = EPHY_LOCATION_ENTRY (header_bar->title_widget);
+    GtkWidget *popover = ephy_add_bookmark_popover_new ();
 
-    g_signal_connect_object (header_bar->title_widget,
-                             "bookmark-clicked",
-                             G_CALLBACK (add_bookmark_button_clicked_cb),
-                             header_bar,
-                             0);
+    ephy_location_entry_set_add_bookmark_popover (lentry, GTK_POPOVER (popover));
   }
 
   /* Fullscreen restore button */
   header_bar->restore_button = gtk_button_new_from_icon_name ("view-restore-symbolic",
                                                               GTK_ICON_SIZE_BUTTON);
-  gtk_widget_set_valign (header_bar->restore_button, GTK_ALIGN_CENTER);
-  g_signal_connect_object (header_bar->restore_button, "clicked",
-                           G_CALLBACK (restore_button_clicked_cb),
-                           header_bar, 0);
-  gtk_header_bar_pack_end (GTK_HEADER_BAR (header_bar),
+  gtk_actionable_set_action_name (GTK_ACTIONABLE (header_bar->restore_button),
+                                  "win.fullscreen");
+  gtk_header_bar_pack_end (GTK_HEADER_BAR (header_bar->header_bar),
                            GTK_WIDGET (header_bar->restore_button));
 
   /* Page Menu */
@@ -261,11 +254,10 @@ ephy_header_bar_constructed (GObject *object)
   header_bar->page_menu_button = button;
   gtk_button_set_image (GTK_BUTTON (button),
                         gtk_image_new_from_icon_name ("open-menu-symbolic", GTK_ICON_SIZE_BUTTON));
-  gtk_widget_set_valign (button, GTK_ALIGN_CENTER);
   g_type_ensure (G_TYPE_THEMED_ICON);
   builder = gtk_builder_new_from_resource ("/org/gnome/epiphany/gtk/page-menu-popover.ui");
-  page_menu_popover = GTK_WIDGET (gtk_builder_get_object (builder, "page-menu-popover"));
-  header_bar->zoom_level_button = GTK_WIDGET (gtk_builder_get_object (builder, "zoom-level"));
+  header_bar->page_menu_popover = GTK_WIDGET (gtk_builder_get_object (builder, "page-menu-popover"));
+  header_bar->zoom_level_label = GTK_WIDGET (gtk_builder_get_object (builder, "zoom-level"));
   if (ephy_embed_shell_get_mode (embed_shell) == EPHY_EMBED_SHELL_MODE_APPLICATION) {
     gtk_widget_destroy (GTK_WIDGET (gtk_builder_get_object (builder, "new-window-separator")));
     gtk_widget_destroy (GTK_WIDGET (gtk_builder_get_object (builder, "new-window-button")));
@@ -278,14 +270,12 @@ ephy_header_bar_constructed (GObject *object)
     gtk_widget_destroy (GTK_WIDGET (gtk_builder_get_object (builder, "override-text-encoding-button")));
     gtk_widget_destroy (GTK_WIDGET (gtk_builder_get_object (builder, "keyboard-shortcuts-button")));
     gtk_widget_destroy (GTK_WIDGET (gtk_builder_get_object (builder, "help-button")));
-    gtk_widget_destroy (GTK_WIDGET (gtk_builder_get_object (builder, "import-export-separator")));
+    gtk_widget_destroy (GTK_WIDGET (gtk_builder_get_object (builder, "firefox-sync-separator")));
+    gtk_widget_destroy (GTK_WIDGET (gtk_builder_get_object (builder, "firefox-sync-button")));
     gtk_widget_destroy (GTK_WIDGET (gtk_builder_get_object (builder, "import-export-menu")));
-  } else if (ephy_is_running_inside_flatpak ()) {
+  } else if (ephy_is_running_inside_sandbox ()) {
     gtk_widget_destroy (GTK_WIDGET (gtk_builder_get_object (builder, "run-in-background-separator")));
     gtk_widget_destroy (GTK_WIDGET (gtk_builder_get_object (builder, "run-in-background-button")));
-    gtk_widget_destroy (GTK_WIDGET (gtk_builder_get_object (builder, "save-as-application-separator")));
-    gtk_widget_destroy (GTK_WIDGET (gtk_builder_get_object (builder, "save-as-application-button")));
-    gtk_widget_destroy (GTK_WIDGET (gtk_builder_get_object (builder, "application-manager-button")));
 
     if (is_desktop_pantheon ())
       gtk_widget_destroy (GTK_WIDGET (gtk_builder_get_object (builder, "help-button")));
@@ -294,6 +284,12 @@ ephy_header_bar_constructed (GObject *object)
     gtk_widget_destroy (GTK_WIDGET (gtk_builder_get_object (builder, "run-in-background-button")));
   }
 
+  if (!ephy_can_install_web_apps ()) {
+    gtk_widget_destroy (GTK_WIDGET (gtk_builder_get_object (builder, "save-as-application-separator")));
+    gtk_widget_destroy (GTK_WIDGET (gtk_builder_get_object (builder, "save-as-application-button")));
+    gtk_widget_destroy (GTK_WIDGET (gtk_builder_get_object (builder, "application-manager-button")));
+  }
+
   header_bar->combined_stop_reload_button = GTK_WIDGET (gtk_builder_get_object (builder, "combined_stop_reload_button"));
   header_bar->combined_stop_reload_image = GTK_WIDGET (gtk_builder_get_object (builder, "combined_stop_reload_image"));
   gtk_widget_set_tooltip_text (header_bar->combined_stop_reload_button, _(REFRESH_BUTTON_TOOLTIP));
@@ -305,11 +301,12 @@ ephy_header_bar_constructed (GObject *object)
                           gtk_image_new_from_icon_name ("open-menu",
                                                         GTK_ICON_SIZE_LARGE_TOOLBAR));
   }
+  g_settings_bind (EPHY_SETTINGS_WEB, EPHY_PREFS_WEB_ENABLE_WEBEXTENSIONS, gtk_builder_get_object (builder, "extensions-button"), "visible", G_SETTINGS_BIND_DEFAULT);
 
-  gtk_menu_button_set_popover (GTK_MENU_BUTTON (button), page_menu_popover);
+  gtk_menu_button_set_popover (GTK_MENU_BUTTON (button), header_bar->page_menu_popover);
   g_object_unref (builder);
 
-  gtk_header_bar_pack_end (GTK_HEADER_BAR (header_bar), button);
+  gtk_header_bar_pack_end (GTK_HEADER_BAR (header_bar->header_bar), button);
 
   /* End action elements */
   header_bar->action_bar_end = ephy_action_bar_end_new ();
@@ -322,7 +319,7 @@ ephy_header_bar_constructed (GObject *object)
   gtk_revealer_set_transition_type (GTK_REVEALER (header_bar->end_revealer), GTK_REVEALER_TRANSITION_TYPE_SLIDE_LEFT);
   gtk_container_add (GTK_CONTAINER (header_bar->end_revealer), GTK_WIDGET (header_bar->action_bar_end));
 
-  gtk_header_bar_pack_end (GTK_HEADER_BAR (header_bar),
+  gtk_header_bar_pack_end (GTK_HEADER_BAR (header_bar->header_bar),
                            GTK_WIDGET (header_bar->end_revealer));
 
   /* Sync the size of placeholder in EphyActionBarStart with downloads button */
@@ -336,10 +333,20 @@ ephy_header_bar_constructed (GObject *object)
   if (ephy_profile_dir_is_web_application ()) {
     GtkWidget *navigation_box = ephy_action_bar_start_get_navigation_box (header_bar->action_bar_start);
 
-    g_settings_bind (EPHY_SETTINGS_WEB_APP, EPHY_PREFS_WEB_APP_MOBILE_CAPABLE, navigation_box, "visible", G_SETTINGS_BIND_GET | G_SETTINGS_BIND_INVERT_BOOLEAN);
+    g_settings_bind (EPHY_SETTINGS_WEB_APP, EPHY_PREFS_WEB_APP_SHOW_NAVIGATION_BUTTONS, navigation_box, "visible", G_SETTINGS_BIND_GET | G_SETTINGS_BIND_INVERT_BOOLEAN);
   }
 }
 
+static void
+ephy_header_bar_dispose (GObject *object)
+{
+  EphyHeaderBar *header_bar = EPHY_HEADER_BAR (object);
+
+  g_clear_handle_id (&header_bar->popover_hide_timeout_id, g_source_remove);
+
+  G_OBJECT_CLASS (ephy_header_bar_parent_class)->dispose (object);
+}
+
 static void
 ephy_header_bar_init (EphyHeaderBar *header_bar)
 {
@@ -353,6 +360,7 @@ ephy_header_bar_class_init (EphyHeaderBarClass *klass)
   gobject_class->set_property = ephy_header_bar_set_property;
   gobject_class->get_property = ephy_header_bar_get_property;
   gobject_class->constructed = ephy_header_bar_constructed;
+  gobject_class->dispose = ephy_header_bar_dispose;
 
   object_properties[PROP_WINDOW] =
     g_param_spec_object ("window",
@@ -372,7 +380,6 @@ ephy_header_bar_new (EphyWindow *window)
   g_assert (EPHY_IS_WINDOW (window));
 
   return GTK_WIDGET (g_object_new (EPHY_TYPE_HEADER_BAR,
-                                   "show-close-button", TRUE,
                                    "window", window,
                                    NULL));
 }
@@ -383,12 +390,6 @@ ephy_header_bar_get_title_widget (EphyHeaderBar *header_bar)
   return header_bar->title_widget;
 }
 
-GtkWidget *
-ephy_header_bar_get_zoom_level_button (EphyHeaderBar *header_bar)
-{
-  return header_bar->zoom_level_button;
-}
-
 GtkWidget *
 ephy_header_bar_get_page_menu_button (EphyHeaderBar *header_bar)
 {
@@ -417,6 +418,9 @@ void
 ephy_header_bar_set_adaptive_mode (EphyHeaderBar    *header_bar,
                                    EphyAdaptiveMode  adaptive_mode)
 {
+  ephy_action_bar_end_set_show_bookmark_button (header_bar->action_bar_end,
+                                                adaptive_mode == EPHY_ADAPTIVE_MODE_NARROW);
+
   switch (adaptive_mode) {
     case EPHY_ADAPTIVE_MODE_NORMAL:
       gtk_revealer_set_reveal_child (GTK_REVEALER (header_bar->start_revealer), TRUE);
@@ -433,7 +437,7 @@ ephy_header_bar_set_adaptive_mode (EphyHeaderBar    *header_bar,
   }
 
   if (ephy_embed_shell_get_mode (ephy_embed_shell_get_default ()) != EPHY_EMBED_SHELL_MODE_APPLICATION)
-    ephy_location_entry_set_mobile_popdown (EPHY_LOCATION_ENTRY (header_bar->title_widget), adaptive_mode == EPHY_ADAPTIVE_MODE_NARROW);
+    ephy_location_entry_set_adaptive_mode (EPHY_LOCATION_ENTRY (header_bar->title_widget), adaptive_mode);
 }
 
 void
@@ -455,3 +459,19 @@ ephy_header_bar_start_change_combined_stop_reload_state (EphyHeaderBar *header_b
                                  _(REFRESH_BUTTON_TOOLTIP));
   }
 }
+
+void
+ephy_header_bar_set_zoom_level (EphyHeaderBar *header_bar,
+                                gdouble        zoom)
+{
+  g_autofree gchar *zoom_level = g_strdup_printf ("%2.0f%%", zoom * 100);
+
+  gtk_label_set_label (GTK_LABEL (header_bar->zoom_level_label), zoom_level);
+}
+
+void
+ephy_header_bar_add_browser_action (EphyHeaderBar *header_bar,
+                                    GtkWidget     *action)
+{
+  ephy_action_bar_end_add_browser_action (header_bar->action_bar_end, action);
+}
