@@ -3,7 +3,7 @@
  *  Copyright © 2003, 2004 Marco Pesenti Gritti <mpeseng@tin.it>
  *  Copyright © 2003, 2004 Christian Persch
  *  Copyright © 2012 Igalia S.L
- *  Copyright © 2018 Jan-Michael Brummer
+ *  Copyright © 2018-2022 Jan-Michael Brummer
  *  Copyright © 2019 Purism SPC
  *
  *  This file is part of Epiphany.
@@ -26,6 +26,8 @@
 #include "ephy-history-dialog.h"
 
 #include "ephy-debug.h"
+#include "ephy-embed-prefs.h"
+#include "ephy-favicon-helpers.h"
 #include "ephy-gui.h"
 #include "ephy-prefs.h"
 #include "ephy-settings.h"
@@ -195,15 +197,14 @@ static void
 set_selection_active (EphyHistoryDialog *self,
                       gboolean           selection_active)
 {
-  g_autoptr (GList) rows = gtk_container_get_children (GTK_CONTAINER (self->listbox));
-  GList *iter = NULL;
+  GtkListBoxRow *row;
+  int i = 0;
 
   self->selection_active = selection_active;
 
-  for (iter = rows; iter != NULL; iter = g_list_next (iter)) {
-    GObject *row = iter->data;
-    GtkWidget *check_button = GTK_WIDGET (g_object_get_data (row, "check-button"));
-    GtkWidget *separator = GTK_WIDGET (g_object_get_data (row, "separator"));
+  while ((row = gtk_list_box_get_row_at_index (GTK_LIST_BOX (self->listbox), i++))) {
+    GtkWidget *check_button = GTK_WIDGET (g_object_get_data (G_OBJECT (row), "check-button"));
+    GtkWidget *separator = GTK_WIDGET (g_object_get_data (G_OBJECT (row), "separator"));
 
     /* Uncheck all rows when toggling selection mode */
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (check_button), FALSE);
@@ -254,15 +255,10 @@ get_url_from_row (GtkListBoxRow *row)
 static void
 clear_listbox (GtkWidget *listbox)
 {
-  GList *children, *iter;
+  GtkListBoxRow *row;
 
-  children = gtk_container_get_children (GTK_CONTAINER (listbox));
-
-  for (iter = children; iter; iter = g_list_next (iter)) {
-    gtk_widget_destroy (GTK_WIDGET (iter->data));
-  }
-
-  g_list_free (children);
+  while ((row = gtk_list_box_get_row_at_index (GTK_LIST_BOX (listbox), 0)))
+    gtk_container_remove (GTK_CONTAINER (listbox), GTK_WIDGET (row));
 }
 
 static void
@@ -345,13 +341,13 @@ filter_now (EphyHistoryDialog *self)
 static GList *
 get_checked_rows (EphyHistoryDialog *self)
 {
-  g_autoptr (GList) rows_list = gtk_container_get_children (GTK_CONTAINER (self->listbox));
   GList *checked_rows = NULL;
-  GList *iter = NULL;
+  GtkListBoxRow *row;
+  int i = 0;
 
-  for (iter = rows_list; iter != NULL; iter = g_list_next (iter)) {
-    GObject *row = iter->data;
-    GtkCheckButton *check_button = GTK_CHECK_BUTTON (g_object_get_data (row, "check-button"));
+  while ((row = gtk_list_box_get_row_at_index (GTK_LIST_BOX (self->listbox), i++))) {
+    GtkCheckButton *check_button =
+      GTK_CHECK_BUTTON (g_object_get_data (G_OBJECT (row), "check-button"));
 
     if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (check_button)))
       checked_rows = g_list_prepend (checked_rows, row);
@@ -423,11 +419,39 @@ row_check_button_toggled (GtkCheckButton    *check_button,
   set_is_selection_empty (self, n_rows == 0);
 }
 
+static void
+ephy_history_dialog_row_favicon_loaded_cb (GObject      *source,
+                                           GAsyncResult *result,
+                                           gpointer      user_data)
+{
+  g_autoptr (GtkWidget) icon = user_data;
+  WebKitFaviconDatabase *database = WEBKIT_FAVICON_DATABASE (source);
+  cairo_surface_t *icon_surface;
+  g_autoptr (GdkPixbuf) favicon = NULL;
+  g_autoptr (GError) error = NULL;
+
+  icon_surface = webkit_favicon_database_get_favicon_finish (database, result, &error);
+  if (g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED))
+    return;
+
+  if (icon_surface) {
+    int scale = gtk_widget_get_scale_factor (icon);
+
+    favicon = ephy_pixbuf_get_from_surface_scaled (icon_surface, FAVICON_SIZE * scale, FAVICON_SIZE * scale);
+    cairo_surface_destroy (icon_surface);
+  }
+
+  if (favicon && icon)
+    gtk_image_set_from_gicon (GTK_IMAGE (icon), G_ICON (favicon), GTK_ICON_SIZE_BUTTON);
+}
+
 static GtkWidget *
 create_row (EphyHistoryDialog *self,
             EphyHistoryURL    *url)
 {
   EphyEmbedShell *shell = ephy_embed_shell_get_default ();
+  WebKitFaviconDatabase *database;
+  GtkWidget *icon;
   GtkWidget *date;
   GtkWidget *row;
   GtkWidget *separator;
@@ -441,6 +465,18 @@ create_row (EphyHistoryDialog *self,
   gtk_list_box_row_set_activatable (GTK_LIST_BOX_ROW (row), TRUE);
   gtk_widget_set_tooltip_text (row, url->url);
 
+  /* Fav Icon */
+  icon = gtk_image_new ();
+  gtk_image_set_pixel_size (GTK_IMAGE (icon), 16);
+  hdy_action_row_add_prefix (HDY_ACTION_ROW (row), icon);
+
+  database = webkit_web_context_get_favicon_database (ephy_embed_shell_get_web_context (shell));
+  webkit_favicon_database_get_favicon (database,
+                                       url->url,
+                                       self->cancellable,
+                                       (GAsyncReadyCallback)ephy_history_dialog_row_favicon_loaded_cb,
+                                       g_object_ref (icon));
+
   /* Date */
   date = gtk_label_new (ephy_time_helpers_utf_friendly_time (url->last_visit_time / 1000000));
   gtk_label_set_ellipsize (GTK_LABEL (date), PANGO_ELLIPSIZE_END);
@@ -489,15 +525,14 @@ add_urls_source (EphyHistoryDialog *self)
   EphyHistoryURL *url;
   GList *element;
   GtkWidget *row;
-  GList *children;
+  gboolean has_results;
 
   set_is_loading (self, FALSE);
 
-  children = gtk_container_get_children (GTK_CONTAINER (self->listbox));
-  set_has_search_results (self, !!children);
-  if (!children)
+  has_results = !!gtk_list_box_get_row_at_index (GTK_LIST_BOX (self->listbox), 0);
+  set_has_search_results (self, has_results);
+  if (!has_results)
     set_has_data (self, FALSE);
-  g_list_free (children);
 
   if (!self->urls || !self->num_fetch) {
     self->sorter_source = 0;
@@ -630,7 +665,7 @@ on_key_press_event (EphyHistoryDialog *self,
     if (focus == last) {
       load_further_data (self);
 
-      return GDK_EVENT_STOP;
+      return GDK_EVENT_PROPAGATE;
     }
   }
 
@@ -729,12 +764,12 @@ handle_selection_row_activated_event (EphyHistoryDialog *self,
   } else {
     /* If there are zero or more than one other rows checked,
      * then we check the clicked row and uncheck all the others */
-    g_autoptr (GList) rows = gtk_container_get_children (GTK_CONTAINER (self->listbox));
-    GList *iter = NULL;
+    GtkListBoxRow *row;
+    int i = 0;
 
-    for (iter = rows; iter != NULL; iter = g_list_next (iter)) {
-      GObject *row = iter->data;
-      GtkCheckButton *row_check_btn = GTK_CHECK_BUTTON (g_object_get_data (row, "check-button"));
+    while ((row = gtk_list_box_get_row_at_index (GTK_LIST_BOX (self->listbox), i++))) {
+      GtkCheckButton *row_check_btn =
+        GTK_CHECK_BUTTON (g_object_get_data (G_OBJECT (row), "check-button"));
 
       gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (row_check_btn), FALSE);
     }
