@@ -23,7 +23,6 @@
 #include "ephy-location-controller.h"
 
 #include "ephy-debug.h"
-#include "ephy-dnd.h"
 #include "ephy-embed-container.h"
 #include "ephy-embed-utils.h"
 #include "ephy-link.h"
@@ -80,82 +79,34 @@ G_DEFINE_TYPE_WITH_CODE (EphyLocationController, ephy_location_controller, G_TYP
                                                 NULL))
 
 static void
-entry_drag_data_received_cb (GtkWidget              *widget,
-                             GdkDragContext         *context,
-                             gint                    x,
-                             gint                    y,
-                             GtkSelectionData       *selection_data,
-                             guint                   info,
-                             guint                   time,
-                             EphyLocationController *controller)
-{
-  GtkEntry *entry;
-  GdkAtom url_type;
-  GdkAtom text_type;
-  const guchar *sel_data;
-
-  sel_data = gtk_selection_data_get_data (selection_data);
-
-  url_type = gdk_atom_intern (EPHY_DND_URL_TYPE, FALSE);
-  text_type = gdk_atom_intern (EPHY_DND_TEXT_TYPE, FALSE);
-
-  if (gtk_selection_data_get_length (selection_data) <= 0 || sel_data == NULL)
-    return;
-
-  entry = GTK_ENTRY (widget);
-
-  if (gtk_selection_data_get_target (selection_data) == url_type) {
-    char **uris;
-
-    uris = g_uri_list_extract_uris ((char *)sel_data);
-    if (uris != NULL && uris[0] != NULL && *uris[0] != '\0') {
-      gtk_entry_set_text (entry, (char *)uris[0]);
-      ephy_link_open (EPHY_LINK (controller),
-                      uris[0],
-                      NULL,
-                      ephy_link_flags_from_current_event ());
-    }
-    g_strfreev (uris);
-  } else if (gtk_selection_data_get_target (selection_data) == text_type) {
-    char *address;
-
-    gtk_entry_set_text (entry, (const gchar *)sel_data);
-    address = ephy_embed_utils_normalize_or_autosearch_address ((const gchar *)sel_data);
-    ephy_link_open (EPHY_LINK (controller),
-                    address,
-                    NULL,
-                    ephy_link_flags_from_current_event ());
-    g_free (address);
-  }
-}
-
-static void
-entry_activate_cb (GtkEntry               *entry,
+entry_activate_cb (EphyLocationEntry      *entry,
+                   GdkModifierType         modifiers,
                    EphyLocationController *controller)
 {
   const char *content;
   char *address;
   char *effective_address;
+  GtkWidget *inner_entry;
 
   if (controller->sync_address_is_blocked) {
     controller->sync_address_is_blocked = FALSE;
     g_signal_handlers_unblock_by_func (controller, G_CALLBACK (sync_address), entry);
   }
 
-  content = gtk_entry_get_text (entry);
+  inner_entry = ephy_location_entry_get_entry (entry);
+  content = gtk_entry_get_text (GTK_ENTRY (inner_entry));
   if (content == NULL || content[0] == '\0')
     return;
 
   if (g_str_has_prefix (content, "ephy-tab://")) {
-    GtkWidget *notebook = ephy_window_get_notebook (controller->window);
+    EphyTabView *tab_view = ephy_window_get_tab_view (controller->window);
     GtkWidget *tab;
     EphyWebView *webview;
-    gint current = gtk_notebook_get_current_page (GTK_NOTEBOOK (notebook));
     g_auto (GStrv) split = g_strsplit (content + strlen ("ephy-tab://"), "@", -1);
 
     g_assert (g_strv_length (split) == 2);
 
-    tab = gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook), current);
+    tab = ephy_tab_view_get_selected_page (tab_view);
     webview = ephy_embed_get_web_view (EPHY_EMBED (tab));
 
     if (atoi (split[1]) != 0) {
@@ -169,15 +120,15 @@ entry_activate_cb (GtkEntry               *entry,
       windows = gtk_application_get_windows (GTK_APPLICATION (application));
 
       window = g_list_nth_data (windows, atoi (split[1]));
-      notebook = ephy_window_get_notebook (window);
+      tab_view = ephy_window_get_tab_view (window);
 
       gtk_window_present (GTK_WINDOW (window));
     }
 
-    gtk_notebook_set_current_page (GTK_NOTEBOOK (notebook), atoi (split[0]));
+    ephy_tab_view_select_nth_page (tab_view, atoi (split[0]));
 
     if (ephy_web_view_is_overview (webview))
-      g_signal_emit_by_name (GTK_NOTEBOOK (notebook), "tab-close-request", tab);
+      ephy_tab_view_close (tab_view, tab);
 
     return;
   }
@@ -203,7 +154,7 @@ entry_activate_cb (GtkEntry               *entry,
 #endif
 
   ephy_link_open (EPHY_LINK (controller), effective_address, NULL,
-                  ephy_link_flags_from_current_event () | EPHY_LINK_TYPED);
+                  ephy_link_flags_from_modifiers (modifiers, FALSE) | EPHY_LINK_TYPED);
 
   g_free (effective_address);
 }
@@ -295,10 +246,7 @@ focus_out_event_cb (GtkWidget              *entry,
 }
 
 static void
-switch_page_cb (GtkNotebook            *notebook,
-                GtkWidget              *page,
-                guint                   page_num,
-                EphyLocationController *controller)
+notify_selected_index_cb (EphyLocationController *controller)
 {
   if (controller->sync_address_is_blocked == TRUE) {
     controller->sync_address_is_blocked = FALSE;
@@ -318,22 +266,16 @@ longpress_gesture_cb (GtkGestureLongPress *gesture,
 }
 
 static void
-reader_mode_button_press_event_cb (GtkWidget *widget,
-                                   GdkEvent  *event,
-                                   gpointer   user_data)
+reader_mode_changed_cb (EphyLocationEntry *lentry,
+                        gboolean           active,
+                        gpointer           user_data)
 {
   EphyLocationController *controller = EPHY_LOCATION_CONTROLLER (user_data);
   EphyWindow *window = controller->window;
   EphyEmbed *embed = ephy_embed_container_get_active_child (EPHY_EMBED_CONTAINER (window));
   EphyWebView *view = ephy_embed_get_web_view (embed);
-  EphyLocationEntry *lentry;
 
-  g_assert (EPHY_IS_LOCATION_ENTRY (controller->title_widget));
-
-  lentry = EPHY_LOCATION_ENTRY (controller->title_widget);
-
-  ephy_location_entry_set_reader_mode_state (lentry, !ephy_location_entry_get_reader_mode_state (lentry));
-  ephy_web_view_toggle_reader_mode (view, ephy_location_entry_get_reader_mode_state (lentry));
+  ephy_web_view_toggle_reader_mode (view, active);
 }
 
 static void
@@ -343,15 +285,17 @@ ephy_location_controller_constructed (GObject *object)
   EphyHistoryService *history_service;
   EphyBookmarksManager *bookmarks_manager;
   EphySuggestionModel *model;
-  GtkWidget *notebook, *widget, *reader_mode, *entry;
+  EphyTabView *tab_view;
+  GtkWidget *widget, *entry;
 
   G_OBJECT_CLASS (ephy_location_controller_parent_class)->constructed (object);
 
-  notebook = ephy_window_get_notebook (controller->window);
+  tab_view = ephy_window_get_tab_view (controller->window);
   widget = GTK_WIDGET (controller->title_widget);
 
-  g_signal_connect (notebook, "switch-page",
-                    G_CALLBACK (switch_page_cb), controller);
+  g_signal_connect_object (tab_view, "notify::selected-index",
+                           G_CALLBACK (notify_selected_index_cb), controller,
+                           G_CONNECT_SWAPPED);
 
   sync_address (controller, NULL, widget);
   g_signal_connect_object (controller, "notify::address",
@@ -373,17 +317,14 @@ ephy_location_controller_constructed (GObject *object)
   dzl_suggestion_entry_set_model (DZL_SUGGESTION_ENTRY (entry), G_LIST_MODEL (model));
   g_object_unref (model);
 
-  reader_mode = ephy_location_entry_get_reader_mode_widget (EPHY_LOCATION_ENTRY (controller->title_widget));
-  g_signal_connect (G_OBJECT (reader_mode), "button-press-event", G_CALLBACK (reader_mode_button_press_event_cb), controller);
+  g_signal_connect (controller->title_widget, "reader-mode-changed",
+                    G_CALLBACK (reader_mode_changed_cb), controller);
 
   g_object_bind_property (controller, "editable",
                           entry, "editable",
                           G_BINDING_SYNC_CREATE);
 
-  g_signal_connect_object (widget, "drag-data-received",
-                           G_CALLBACK (entry_drag_data_received_cb),
-                           controller, 0);
-  g_signal_connect_object (entry, "activate",
+  g_signal_connect_object (widget, "activate",
                            G_CALLBACK (entry_activate_cb),
                            controller, 0);
   g_signal_connect_object (widget, "get-location",
@@ -446,14 +387,9 @@ static void
 ephy_location_controller_dispose (GObject *object)
 {
   EphyLocationController *controller = EPHY_LOCATION_CONTROLLER (object);
-  GtkWidget *notebook;
 
-  notebook = ephy_window_get_notebook (controller->window);
-
-  if (notebook == NULL ||
-      controller->title_widget == NULL) {
+  if (!controller->title_widget)
     return;
-  }
 
   g_clear_object (&controller->longpress_gesture);
 
@@ -463,8 +399,6 @@ ephy_location_controller_dispose (GObject *object)
     g_signal_handlers_disconnect_matched (controller->title_widget, G_SIGNAL_MATCH_DATA,
                                           0, 0, NULL, NULL, controller);
   }
-  g_signal_handlers_disconnect_matched (notebook, G_SIGNAL_MATCH_DATA,
-                                        0, 0, NULL, NULL, controller);
   controller->title_widget = NULL;
 
   G_OBJECT_CLASS (ephy_location_controller_parent_class)->dispose (object);
