@@ -25,6 +25,7 @@
 #include "ephy-debug.h"
 #include "ephy-embed-utils.h"
 #include "ephy-file-helpers.h"
+#include "ephy-flatpak-utils.h"
 #include "ephy-profile-utils.h"
 #include "ephy-session.h"
 #include "ephy-settings.h"
@@ -181,6 +182,8 @@ main (int   argc,
   g_setenv ("GSETTINGS_SCHEMA_DIR", BUILD_ROOT "/data", FALSE);
 #endif
 
+  g_setenv ("PULSE_PROP_application.icon_name", APPLICATION_ID, TRUE);
+
   /* Initialize the i18n stuff */
   bindtextdomain (GETTEXT_PACKAGE, LOCALEDIR);
   bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
@@ -292,14 +295,19 @@ main (int   argc,
 
   if (application_mode && !profile_directory) {
     if (desktop_file_basename) {
-      desktop_info = g_desktop_app_info_new (desktop_file_basename);
-
-      if (desktop_info)
-        profile_directory = ephy_web_application_ensure_for_app_info (G_APP_INFO (desktop_info));
-
-      if (!profile_directory) {
-        g_print ("Invalid desktop file passed to --application-mode\n");
+      if (ephy_is_running_inside_sandbox ()) {
+        g_print ("In sandbox, no desktop file can be passed to --application-mode\n");
         exit (1);
+      } else {
+        desktop_info = g_desktop_app_info_new (desktop_file_basename);
+
+        if (desktop_info)
+          profile_directory = ephy_web_application_ensure_for_app_info (G_APP_INFO (desktop_info));
+
+        if (!profile_directory) {
+          g_print ("Invalid desktop file passed to --application-mode\n");
+          exit (1);
+        }
       }
     }
   }
@@ -319,8 +327,6 @@ main (int   argc,
     flags |= EPHY_FILE_HELPERS_PRIVATE_PROFILE;
   if (incognito_mode)
     flags |= EPHY_FILE_HELPERS_STEAL_DATA;
-  if (profile_directory && !incognito_mode)
-    flags |= EPHY_FILE_HELPERS_KEEP_DIR;
 
   if (!ephy_file_helpers_init (profile_directory, flags, &error)) {
     g_error ("Fatal initialization error: %s", error->message);
@@ -370,7 +376,7 @@ main (int   argc,
   /* Delete the requested web application, if any. Must happen after
    * ephy_file_helpers_init (). */
   if (application_to_delete) {
-    ephy_web_application_delete (application_to_delete);
+    ephy_web_application_delete (application_to_delete, NULL);
     exit (0);
   }
 
