@@ -27,8 +27,20 @@
 
 G_BEGIN_DECLS
 
-char *ephy_web_extension_api_tabs_handler (EphyWebExtension *self,
-                                           char             *name,
-                                           JSCValue         *value);
+void ephy_web_extension_api_tabs_handler (EphyWebExtensionSender *sender,
+                                          const char             *method_name,
+                                          JsonArray              *args,
+                                          GTask                  *task);
+
+JsonNode *ephy_web_extension_api_tabs_create_tab_object (EphyWebExtension *self,
+                                                         EphyWebView      *web_view);
+
+void      ephy_web_extension_api_tabs_add_tab_to_json   (EphyWebExtension *self,
+                                                         JsonBuilder      *builder,
+                                                         EphyWindow       *window,
+                                                         EphyWebView      *web_view);
+
+gboolean  ephy_web_extension_api_tabs_url_is_unprivileged
+                                                        (const char       *url);
 
 G_END_DECLS
